@@ -21,12 +21,12 @@
 #include <acl/libacl.h>
 #endif
 
-#include "filebuffer.h"
-#include "fileline.h"
-#include "filestate.h"
-#include "log.h"
-#include "openfiles.h"
-#include "option.h"
+#include "tilde/filebuffer.h"
+#include "tilde/fileline.h"
+#include "tilde/filestate.h"
+#include "tilde/log.h"
+#include "tilde/openfiles.h"
+#include "tilde/option.h"
 
 #define CREATE_MODE (S_IRUSR | S_IWUSR | S_IRGRP | S_IWGRP | S_IROTH | S_IWOTH)
 
@@ -291,7 +291,8 @@ rw_result_t file_buffer_t::save(save_as_process_t *state) {
              directly. The latter has some risk (e.g. file truncation due to full disk,
              or corruption due to computer crashes), but these are so small that it is
              worth permitting this if we can't create the temporary file. */
-          if ((state->fd = mkstemp(temp_name.data())) >= 0) {
+          if (geteuid() == state->file_info.st_uid &&
+              (state->fd = mkstemp(temp_name.data())) >= 0) {
             state->temp_name = temp_name.data();
 // Preserve ownership and attributes
 #ifdef HAS_LIBATTR
@@ -599,7 +600,8 @@ bool file_buffer_t::find_matching_brace(text_coordinate_t &match_location) {
        opening brace is on this line (because we count up to, but not
        including, the closing brace here).
     */
-    for (i = 0; i < cursor.pos; i = line->adjust_position(i, 1)) {
+    const int max = std::max(cursor.pos, line->get_length());
+    for (i = 0; i < max; i = line->adjust_position(i, 1)) {
       check_c = (*(line->get_data()))[i];
       if ((check_c != c && check_c != c_close) || line->get_highlight_idx(i) > 0) {
         continue;
@@ -816,3 +818,17 @@ void file_buffer_t::toggle_line_comment() {
     set_selection_end();
   }
 }
+
+const char *file_buffer_t::get_char_under_cursor(size_t *size) const {
+  const text_line_t *line = get_line_data(cursor.line);
+  if (cursor.pos >= line->get_length()) {
+    *size = 1;
+    return "\n";
+  }
+  int end = line->adjust_position(cursor.pos, 1);
+  if (cursor.pos == end) {
+    return nullptr;
+  }
+  *size = end - cursor.pos;
+  return line->get_data()->data() + cursor.pos;
+}
