@@ -14,7 +14,7 @@
 #ifndef FILE_EDIT_WINDOW_T
 #define FILE_EDIT_WINDOW_T
 
-#include "filebuffer.h"
+#include "tilde/filebuffer.h"
 #include <t3widget/widget.h>
 
 using namespace t3_widget;
@@ -34,6 +34,7 @@ class file_edit_window_t : public edit_window_t {
   void set_text(file_buffer_t *_text);
   file_buffer_t *get_text() const;
   void goto_matching_brace();
+  void show_character_details();
 };
 
 #endif
