@@ -18,19 +18,20 @@
 #include <t3widget/key_binding.h>
 #include <t3widget/widget.h>
 
-#include "action.h"
-#include "dialogs/attributesdialog.h"
-#include "dialogs/encodingdialog.h"
-#include "dialogs/highlightdialog.h"
-#include "dialogs/openrecentdialog.h"
-#include "dialogs/optionsdialog.h"
-#include "dialogs/selectbufferdialog.h"
-#include "filebuffer.h"
-#include "fileeditwindow.h"
-#include "log.h"
-#include "openfiles.h"
-#include "option.h"
-#include "string_util.h"
+#include "tilde/action.h"
+#include "tilde/dialogs/attributesdialog.h"
+#include "tilde/dialogs/characterdetailsdialog.h"
+#include "tilde/dialogs/encodingdialog.h"
+#include "tilde/dialogs/highlightdialog.h"
+#include "tilde/dialogs/openrecentdialog.h"
+#include "tilde/dialogs/optionsdialog.h"
+#include "tilde/dialogs/selectbufferdialog.h"
+#include "tilde/filebuffer.h"
+#include "tilde/fileeditwindow.h"
+#include "tilde/log.h"
+#include "tilde/openfiles.h"
+#include "tilde/option.h"
+#include "tilde/string_util.h"
 
 using namespace t3_widget;
 
@@ -45,6 +46,7 @@ message_dialog_t *error_dialog;
 open_recent_dialog_t *open_recent_dialog;
 encoding_dialog_t *encoding_dialog;
 message_dialog_t *preserve_bom_dialog;
+character_details_dialog_t *character_details_dialog;
 
 static dialog_t *input_selection_dialog;
 
@@ -141,6 +143,7 @@ main_t::main_t() {
   panel->add_item("Paste _Selection", "S-Ins", action_id_t::EDIT_PASTE_SELECTION);
   panel->add_separator();
   panel->add_item("_Delete Line", "^K", action_id_t::EDIT_DELETE_LINE);
+  panel->add_item("Character Detai_ls...", "F2", action_id_t::EDIT_CHAR_DETAILS);
   panel->add_item("Insert C_haracter...", "F9", action_id_t::EDIT_INSERT_CHAR);
   panel->add_item("T_oggle INS/OVR", "Ins", action_id_t::EDIT_TOGGLE_INSERT);
 
@@ -233,7 +236,7 @@ main_t::main_t() {
   about_dialog->set_max_text_height(13);
   about_dialog->set_message(
       // clang-format off
-      "Tilde - The intuitive text editor\n\nVersion 0.4.0\n"
+      "Tilde - The intuitive text editor\n\nVersion 0.4.3\n"
       "Copyright (c) 2011-2018 G.P. Halkes\n\n"  // @copyright
       "The Tilde text editor is licensed under the GNU General Public License version 3. "
       "You should have received a copy of the GNU General Public License along with this program. "
@@ -263,6 +266,9 @@ main_t::main_t() {
       "however, the presence of the BOM is undesirable. Do you want to preserve the BOM?");
   preserve_bom_dialog->center_over(this);
 
+  character_details_dialog = new character_details_dialog_t(8, MESSAGE_DIALOG_WIDTH);
+  character_details_dialog->center_over(this);
+
   attributes_dialog = new attributes_dialog_t(ATTRIBUTES_DIALOG_WIDTH);
   attributes_dialog->center_over(this);
   attributes_dialog->connect_activate(signals::mem_fun(this, &main_t::set_interface_options));
@@ -394,6 +400,9 @@ void main_t::menu_activated(int id) {
     case action_id_t::EDIT_PASTE_SELECTION:
       get_current()->paste_selection();
       break;
+    case action_id_t::EDIT_CHAR_DETAILS:
+      get_current()->show_character_details();
+      break;
     case action_id_t::EDIT_INSERT_CHAR:
       get_current()->insert_special();
       break;
