@@ -17,8 +17,9 @@
 #include <t3widget/widget.h>
 using namespace t3_widget;
 
-#include "dialogs/encodingdialog.h"
-#include "dialogs/openrecentdialog.h"
+#include "tilde/dialogs/characterdetailsdialog.h"
+#include "tilde/dialogs/encodingdialog.h"
+#include "tilde/dialogs/openrecentdialog.h"
 
 extern message_dialog_t *continue_abort_dialog;
 extern open_file_dialog_t *open_file_dialog;
@@ -28,4 +29,6 @@ extern message_dialog_t *error_dialog;
 extern open_recent_dialog_t *open_recent_dialog;
 extern encoding_dialog_t *encoding_dialog;
 extern message_dialog_t *preserve_bom_dialog;
+extern character_details_dialog_t *character_details_dialog;
+
 #endif
