@@ -18,10 +18,10 @@
 #include <transcript/transcript.h>
 #include <unistring/version.h>
 
-#include "log.h"
-#include "option.h"
-#include "optionMacros.h"
-#include "util.h"
+#include "tilde/log.h"
+#include "tilde/option.h"
+#include "tilde/optionMacros.h"
+#include "tilde/util.h"
 
 using namespace t3_widget;
 
@@ -89,7 +89,7 @@ static const char config_schema[] = {
 };
 
 static const char base_config_schema[] = {
-#include "config.bytes"
+#include "base_config.bytes"
 };
 
 static t3_bool find_term_config(const t3_config_t *config, const void *data) {
@@ -399,15 +399,20 @@ static void post_process_options() {
 
 static void print_help() {
   printf(
-      "Usage: tilde [<OPTIONS>] [<FILE...>]\n"
+      "Usage: tilde [<OPTIONS>] [<FILE...>[:<LINE>[:<COLUMN>]]]\n"
       "  -b,--black-white            Request black & white mode, overriding config file\n"
       "  -c,--color                  Request color mode, overriding config file\n"
       "  -C<file>,--config=<file>    Use <file> as config file\n"
       "  -e<enc>, --encoding=<enc>   Use <enc> as the encoding for loading files from\n"
-      "                                  the command line\n"
+      "                                the command line\n"
       "  -h,--help                   Show this help message.\n"
       "  -I,--select-input-method    Ignore configured input handling method.\n"
       "  --ignore-running            Ignore instances already running on this terminal\n"
+      "  -J,--no-parse-file-position Do not attempt to parse line and column from file\n"
+      "                                names passed on the command line\n"
+      "  -P,--no-primary-selection   Disable the use of the primary selection (i.e.\n"
+      "                                middle mouse-button copy-paste) for external\n"
+      "                                clipboards like X11\n"
       "  -T<term>,--terminal=<term>  Use <term> instead of TERM variable\n"
       "  -V,--version                Show version and copyright information\n"
       "  -x,--no-ext-clipboard       Disable the external (X11) clipboard interface\n");
@@ -416,7 +421,7 @@ static void print_help() {
 
 static void print_version() {
   printf(
-      "Tilde version 0.4.0\n"
+      "Tilde version 0.4.3\n"
       "Copyright (c) 2011-2018 G.P. Halkes\n"  // @copyright
       "Tilde is licensed under the GNU General Public License version 3\n");
   printf(
@@ -439,69 +444,71 @@ static void print_version() {
   exit(EXIT_SUCCESS);
 }
 
+// clang-format off
 PARSE_FUNCTION(parse_args)
-OPTIONS
-OPTION('h', "help", NO_ARG)
-print_help();
-END_OPTION
-OPTION('V', "version", NO_ARG)
-print_version();
-END_OPTION
-OPTION('T', "term", REQUIRED_ARG)
-cli_option.term = optArg;
-END_OPTION
-OPTION('b', "black-white", NO_ARG)
-cli_option.color = false;
-END_OPTION
-OPTION('c', "color", NO_ARG)
-cli_option.color = true;
-END_OPTION
-OPTION('I', "select-input-method", NO_ARG)
-cli_option.ask_input_method = true;
-END_OPTION
-OPTION('x', "no-ext-clipboard", NO_ARG)
-cli_option.disable_external_clipboard = true;
-END_OPTION
-OPTION('P', "no-primary-selection", NO_ARG)
-cli_option.disable_primary_selection = true;
-END_OPTION
-OPTION('C', "config", REQUIRED_ARG)
-cli_option.config_file = optArg;
-END_OPTION
-OPTION('e', "encoding", OPTIONAL_ARG)
-cli_option.encoding = optArg;
-END_OPTION
-LONG_OPTION("ignore-running", NO_ARG)
-cli_option.ignore_running = true;
-END_OPTION
-OPTION('J', "no-parse-file-position", NO_ARG)
-cli_option.disable_file_position_parsing = true;
-END_OPTION
+  OPTIONS
+    OPTION('h', "help", NO_ARG)
+      print_help();
+    END_OPTION
+    OPTION('V', "version", NO_ARG)
+      print_version();
+    END_OPTION
+    OPTION('T', "term", REQUIRED_ARG)
+      cli_option.term = optArg;
+    END_OPTION
+    OPTION('b', "black-white", NO_ARG)
+      cli_option.color = false;
+    END_OPTION
+    OPTION('c', "color", NO_ARG)
+      cli_option.color = true;
+    END_OPTION
+    OPTION('I', "select-input-method", NO_ARG)
+      cli_option.ask_input_method = true;
+    END_OPTION
+    OPTION('x', "no-ext-clipboard", NO_ARG)
+      cli_option.disable_external_clipboard = true;
+    END_OPTION
+    OPTION('P', "no-primary-selection", NO_ARG)
+      cli_option.disable_primary_selection = true;
+    END_OPTION
+    OPTION('C', "config", REQUIRED_ARG)
+      cli_option.config_file = optArg;
+    END_OPTION
+    OPTION('e', "encoding", OPTIONAL_ARG)
+      cli_option.encoding = optArg;
+    END_OPTION
+    LONG_OPTION("ignore-running", NO_ARG)
+      cli_option.ignore_running = true;
+    END_OPTION
+    OPTION('J', "no-parse-file-position", NO_ARG)
+      cli_option.disable_file_position_parsing = true;
+    END_OPTION
 #ifdef DEBUG
-LONG_OPTION("W", NO_ARG)
-cli_option.wait = true;
-END_OPTION
-LONG_OPTION("L", REQUIRED_ARG)
-PARSE_INT(cli_option.vm_limit, -1, INT_MAX / (1024 * 1024));
-END_OPTION
-LONG_OPTION("D", NO_ARG)
-cli_option.start_debugger_on_segfault = true;
-END_OPTION
+    LONG_OPTION("W", NO_ARG)
+      cli_option.wait = true;
+    END_OPTION
+    LONG_OPTION("L", REQUIRED_ARG)
+      PARSE_INT(cli_option.vm_limit, -1, INT_MAX / (1024 * 1024));
+    END_OPTION
+    LONG_OPTION("D", NO_ARG)
+      cli_option.start_debugger_on_segfault = true;
+    END_OPTION
 #endif
-DOUBLE_DASH
-NO_MORE_OPTIONS;
-END_OPTION
+    DOUBLE_DASH
+      NO_MORE_OPTIONS;
+    END_OPTION
 
-fatal("No such option " OPTFMT "\n", OPTPRARG);
-NO_OPTION
-cli_option.files.push_back(optcurrent);
-END_OPTIONS
+    fatal("No such option " OPTFMT "\n", OPTPRARG);
+  NO_OPTION
+    cli_option.files.push_back(optcurrent);
+  END_OPTIONS
 
-read_base_config();
-read_config();
+  read_base_config();
+  read_config();
 
-post_process_options();
+  post_process_options();
 END_FUNCTION
+// clang-format on
 
 #define SET_ATTR_FROM_FILE(name, const_name)                       \
   do {                                                             \
